probePlots <-
    function(abatch, path, pbsList, ...){

        ## check if arguments are ok
        if(missing(abatch) && missing(path))
            stop("** ERROR : 'abatch' or 'path' arguments are empty")
        
        if(missing(pbsList))
            stop("** ERROR : 'pbsList' argument is missing")
        if(class(pbsList)!="character")
            stop("** ERROR : 'pbsList' argument is not a character class")
        
        if(!missing(abatch)){
            if(class(abatch) ==  "AffyBatch")
                abatch <- abatch
            else
                stop("** ERROR : 'abatch' argument is not an AffyBatch class")
        }
        
        if(!missing(path)){
            if(class(path) ==  "character")
                abatch <- ReadAffy(celfile.path=path)
            else
                stop("** ERROR : 'path' argument is not a character class")
        }
        
        ## select the probesets in the affybatch
        pbs <- probeset(abatch, pbsList)
        
        ## prepare the plot
        par(mfrow=c(2,3), bg = "gray80", mai=c(5, 4, 4, 2), mar=c(5, 4, 4, 2), oma=c(0,0,2,0), ...)
        
        for(i in 1:length(pbs)){
            pmi <- pm(pbs[[i]])
            mmi <- mm(pbs[[i]])
            ## INTER CHIPS PLOT
            plot(pbs[[i]], type="l", main=paste("Probeset ", names(pbs)[i], "\nInter chips", sep=""), axes=FALSE, ylab="", xlab="probes", col=rainbow(nrow(pmi)), lty=1:5, ...)
            if(!is.null(rownames(pmi)))
                xlabels <- rownames(pmi)
            else
                xlabels <- as.character(1:nrow(pmi))
            axis(1, 1:nrow(pmi), xlabels, las=2, ...)
            axis(2)
            box()
            if(!is.null(colnames(pmi)))
                legend("topright", colnames(pmi), lty=1:5, col=rainbow(nrow(pmi)), ...)
            
            ## INTER PROBES PLOT - PM
            matplot(t(pmi), type="l", main=paste("Probeset ", names(pbs)[i], "\nInter probes - Perfect Match", sep=""), axes=FALSE, ylab="", xlab="chips", col=rainbow(nrow(pmi)), lty=1:5, ...)
            if(!is.null(colnames(pmi)))
                xlabels <- colnames(pmi)
            else
                xlabels <- as.character(1:ncol(pmi))
            axis(1, 1:ncol(pmi), xlabels, las=2, ...)
            axis(2)
            box()
            if(!is.null(rownames(pmi)))
                legend("topright", rownames(pmi), lty=1:5, col=rainbow(nrow(pmi)), ...)
            else
                legend("topright", as.character(1:nrow(pmi)), lty=1:5, col=rainbow(nrow(pmi)), ...)
            
            ## INTER PROBES PLOT - MM
            matplot(t(mmi), type="l", main=paste("Probeset ", names(pbs)[i], "\nInter probes - Mis Match", sep=""), axes=FALSE, ylab="", xlab="chips", col=rainbow(nrow(mmi)), lty=1:5, ...)
            if(!is.null(colnames(mmi)))
                xlabels <- colnames(mmi)
            else
                xlabels <- as.character(1:ncol(mmi))
            axis(1, 1:ncol(mmi), xlabels, las=2, ...)
            axis(2)
            box()
            if(!is.null(rownames(mmi)))
                legend("topright", rownames(mmi), lty=1:5, col=rainbow(nrow(mmi)), ...)
            else
                legend("topright", as.character(1:nrow(mmi)), lty=1:5, col=rainbow(nrow(mmi)), ...)
            
        }
    }
