\name{keggReport}
\alias{keggReport}

\title{Text report from the result of a call to 'hyperGTest' for KEGG pathway}
\description{
 Create a txt report with the significant probesets for each significant KEGG pathway from the result of a call to 'hyperGTest'
}
\usage{
keggReport(hgOver,fileout = "report.txt", pack.annot, pvalue = 0.05)
}

\arguments{
  \item{hgOver}{result from a call to 'hyperGTest' }
  \item{fileout}{name of txt file, by default "report.txt"}
  \item{pack.annot}{the annotation package to use}
  \item{pvalue}{cutoff for significant pvalue, by default 0.05}
}

\value{
 Txt report with the results of a call to 'hyperGTest'
}

\author{EMA group}

\seealso{\code{\link{hyperGTest}},\code{\link{runHyperKEGG}}}
\examples{
  data(marty)
  ## Probe list
  probeList <- rownames(marty)[1:50]

  ## Create an instance of a subclass of 'HyperGParams'
  designALL <- names(unlist(as.list(hgu133plus2ACCNUM)))
  entrezIds <- mget(designALL, envir = hgu133plus2ENTREZID)
  designKEGG <- names(entrezIds)[sapply(entrezIds, function(x) !is.na(x))]
  entrezUniverse <- unique(unlist(mget(designKEGG, hgu133plus2ENTREZID)))
  listKEGG <- intersect(probeList, designKEGG)
  selectedEntrezIds <- na.omit(unique(unlist(mget(listKEGG, hgu133plus2ENTREZID))))
  params.KEGG.over <-new("KEGGHyperGParams", geneIds=selectedEntrezIds, universeGeneIds=entrezUniverse, annotation = "hgu133plus2.db", pvalueCutoff = 0.05, testDirection="over")
  
  ## Hypergeometric test
  hgOver.KEGG <- hyperGTest(params.KEGG.over)

  ## Txt report
  keggReport(hgOver.KEGG, pack.annot = "hgu133plus2.db")
}

\keyword{htest}

