\name{plotExplore}
\Rdversion{1.1}
\alias{plotExplore}
\title{
Distribution analysis of each column (arrays) of a gene expression matrix
}
\description{
Produces boxplot and density plot of each column (arrays) of a gene expression matrix
}
\usage{
plotExplore(X, pdfname = NULL, pdfwidth = 11.69, pdfheight = 8.27,
bx.range = 1.5, show.names = TRUE, cex.x = 0.6, highlight = NULL,
global.median = FALSE, ...)
}
\arguments{
  \item{X}{
A matrix with p rows (genes) and n columns (arrays)
}
  \item{pdfname}{
pdf file name for saving graphics
}
  \item{pdfwidth}{
The width of the graphics region in inches. The default value is 11.69 
}
  \item{pdfheight}{
The height of the graphics region in inches. The default values is 8.27 respectively 
}
  \item{bx.range}{
This determines how far the plot whiskers extend out from the box. 
If range is positive, the whiskers extend to the most extreme data point which is no more than range times the interquartile range from the box. 
A value of zero causes the whiskers to extend to the data extremes. Default is 1.5.
}
  \item{show.names}{
Set to TRUE or FALSE to override the defaults on whether an x-axis label is printed for each boxplot
}
  \item{cex.x}{
A numerical value giving the magnification to be used for the x axis annotation of the boxplot relative to the current setting of cex
}
  \item{highlight}{
character vector of names of the arrays (column of X) to be highlighted in the graphs
}
  \item{global.median}{
boolean, if TRUE, an  horizontal green line is drawn at the median value of X (for boxplot only)
}
  \item{...}{Arguments to be passed to methods, such as graphical parameters (see 'par').}

}
\details{
Useful to explore the distribution of the expression profile of each sample.
Makes easier the detection of extreme samples.
}

\author{EMA group}

\seealso{
\code{\link{boxplot}}, \code{\link{density}},
}
\examples{
\dontrun{
data(marty)
plotExplore(marty)
plotExplore(marty,pdfname="Exploratory analysis")
plotExplore(marty,pdfname="Exploratory analysis",pdfwidth=7,pdfheight=7)
plotExplore(marty,bx.range=2.5)
plotExplore(marty,show.names=FALSE)
plotExplore(marty,cex.x=0.4) 
tohighlight<-(dimnames(marty)[[2]][c(2,7,9,20)])
plotExplore(marty,highlight=tohighlight) 
plotExplore(marty,pdfname="Exploratory analysis",highlight=tohighlight) 
plotExplore(marty,pdfname="Exploratory analysis",highlight=tohighlight,global.median=TRUE) 
}
}

\keyword{graphs}

